@@ -368,34 +368,6 @@ void dhcpv6_init_header(struct dhcpv6_packet *packet, uint8_t type)
 	packet->transaction_id[2] = id & 0xff;
 }
 
-static bool check_vendor(uint8_t  *option_vendor, const char *vendor)
-{
-	uint8_t vendor_length = sizeof(vendor) - 1;
-
-	if (option_vendor[OPT_LEN - OPT_DATA] != vendor_length)
-		return false;
-
-	if (memcmp(option_vendor, vendor, vendor_length) != 0)
-		return false;
-
-	return true;
-}
-
-static void check_broken_vendor(struct dhcp_packet *packet)
-{
-	uint8_t *vendor;
-
-	if (packet->op != BOOTREQUEST)
-		return;
-
-	vendor = dhcp_get_option(packet, DHCP_VENDOR);
-	if (!vendor)
-		return;
-
-	if (check_vendor(vendor, "MSFT 98"))
-		packet->flags |= htons(BROADCAST_FLAG);
-}
-
 int dhcp_recv_l3_packet(struct dhcp_packet *packet, int fd)
 {
 	int n;
@@ -409,8 +381,6 @@ int dhcp_recv_l3_packet(struct dhcp_packet *packet, int fd)
 	if (packet->cookie != htonl(DHCP_MAGIC))
 		return -EPROTO;
 
-	check_broken_vendor(packet);
-
 	return n;
 }
 
@@ -541,8 +511,9 @@ int dhcpv6_send_packet(int index, struct dhcpv6_packet *dhcp_pkt, int len)
 }
 
 int dhcp_send_raw_packet(struct dhcp_packet *dhcp_pkt,
-		uint32_t source_ip, int source_port, uint32_t dest_ip,
-			int dest_port, const uint8_t *dest_arp, int ifindex)
+			uint32_t source_ip, int source_port,
+			uint32_t dest_ip, int dest_port,
+			const uint8_t *dest_arp, int ifindex, bool bcast)
 {
 	struct sockaddr_ll dest;
 	struct ip_udp_dhcp_packet packet;
@@ -559,6 +530,9 @@ int dhcp_send_raw_packet(struct dhcp_packet *dhcp_pkt,
 	if (fd < 0)
 		return -errno;
 
+	if (bcast)
+		dhcp_pkt->flags |= htons(BROADCAST_FLAG);
+
 	memset(&dest, 0, sizeof(dest));
 	memset(&packet, 0, sizeof(packet));
 	packet.data = *dhcp_pkt;
